@@ -59,14 +59,14 @@ class ZestRunner:
 
             is_libs = True
             real_path = os.path.realpath(file)
-            if real_path.startswith(self.root):
+            if real_path.startswith(self.root) and os.path.exists(real_path):
                 is_libs = False
 
             if "/site-packages/" in file:
                 # Treat these long but commonly occurring path differently
                 file = re.sub(r".*/site-packages/", ".../", file)
             leading, basename = os.path.split(file)
-            leading = f"{'./' if leading[0] != '.' else ''}{leading}"
+            leading = f"{'./' if len(leading) > 0 and leading[0] != '.' else ''}{leading}"
             return leading, basename, lineno, context, is_libs
         return None
 
@@ -172,7 +172,9 @@ class ZestRunner:
 
     def walk(self):
         for folder in self.include_dirs:
-            for curr, dirs, files in os.walk(os.path.abspath(os.path.join(self.root, folder))):
+            for curr, dirs, files in os.walk(
+                os.path.abspath(os.path.join(self.root, folder))
+            ):
                 dirs[:] = [d for d in dirs if d[0] != "."]
                 if curr.endswith("/zests"):
                     yield curr
@@ -199,7 +201,7 @@ class ZestRunner:
         elif self.verbose == 1:
             self.display_abbreviated(name, error, func)
 
-    def _recurse_ast(self, func_body, parent_name, skips):
+    def _recurse_ast(self, func_body, parent_name, skips, path, lineno):
         """
         Args:
             func_body: the AST func_body or module body
@@ -215,6 +217,9 @@ class ZestRunner:
         found_zest_call_before_final_func_def = False
         child_list = []
         for i, part in enumerate(func_body):
+            if isinstance(part, ast.With):
+                child_list += self._recurse_ast(part.body, parent_name, skips, path, part.lineno)
+
             if isinstance(part, ast.FunctionDef):
                 full_name = None
                 if parent_name is None:
@@ -246,7 +251,7 @@ class ZestRunner:
                 if full_name is not None:
                     child_list += [(full_name, set(_groups), _skips)]
                     n_test_funcs += 1
-                    child_list += self._recurse_ast(part.body, full_name, _skips)
+                    child_list += self._recurse_ast(part.body, full_name, _skips, path, part.lineno)
 
                 if found_zest_call:
                     found_zest_call_before_final_func_def = True
@@ -261,19 +266,36 @@ class ZestRunner:
             n_test_funcs > 0
             and parent_name is not None
             and not found_zest_call
-            and (not skips or (skips and self.bypass_skip is not None and self.bypass_skip in skips))
+            and (
+                not skips
+                or (
+                    skips and self.bypass_skip is not None and self.bypass_skip in skips
+                )
+            )
         ):
             ZestRunner.n_zest_missing_errors += 1
             common_wording = "If you are using local functions that are not tests, prefix them with underscore."
             if found_zest_call_before_final_func_def:
                 s(
-                    red,
-                    f"ERROR: Zest function {parent_name} did not call zest() before all functions were defined. {common_wording}",
+                    red, "\nERROR: ",
+                    reset,
+                    "Zest function '",
+                    bold, red,
+                    parent_name,
+                    reset,
+                    f" (@ {path}:{lineno}) ",
+                    f"' did not call zest() before all functions were defined. {common_wording}\n",
                 )
             else:
                 s(
-                    red,
-                    f"ERROR: Zest function {parent_name} did not terminate with a call to zest(). {common_wording}",
+                    red, "\nERROR: ",
+                    reset,
+                    "Zest function '",
+                    bold, red,
+                    parent_name,
+                    reset,
+                    f" (@ {path}:{lineno}) ",
+                    f"' did not terminate with a call to zest(). {common_wording}\n",
                 )
 
         return child_list
@@ -336,7 +358,7 @@ class ZestRunner:
                     source = f.read()
 
                 module_ast = ast.parse(source)
-                zests = self._recurse_ast(module_ast.body, None, None)
+                zests = self._recurse_ast(module_ast.body, None, None, path, 0)
 
                 for full_name, member_groups, skips in zests:
                     # If the requested substring is anywhere in the full_name
@@ -386,17 +408,30 @@ class ZestRunner:
 
                 if self.verbose > 2:
                     marker = "?" if self.add_markers else ""
-                    s(cyan, marker + root_name, gray, f" module_name={module_name}, package={package}, member_groups={member_groups}: ")
+                    s(
+                        cyan,
+                        marker + root_name,
+                        gray,
+                        f" module_name={module_name}, package={package}, member_groups={member_groups}: ",
+                    )
 
                 if is_test_in_a_skpped_group:
                     if self.verbose > 2:
                         s(cyan, f"Skipping\n")
 
                     self._test_start_callback(root_name, [], None)
-                    self._test_stop_callback(root_name, [], "skipped because it is in a skipped group", 0.0, None)
+                    self._test_stop_callback(
+                        root_name,
+                        [],
+                        "skipped because it is in a skipped group",
+                        0.0,
+                        None,
+                    )
                     continue
 
-                if (run_group in member_groups or run_group == "*") and not has_run.get(root_name):
+                if (run_group in member_groups or run_group == "*") and not has_run.get(
+                    root_name
+                ):
                     if self.verbose > 2:
                         s(cyan, f"Running\n")
 
@@ -437,10 +472,14 @@ class ZestRunner:
 
             self.display_warnings(zest._call_warnings)
 
+
 def main():
     parser = argparse.ArgumentParser()
     parser.add_argument(
-        "--verbose", default=1, type=int, help="0=silent, 1=dot-mode, 2=run-trace 3=full-trace",
+        "--verbose",
+        default=1,
+        type=int,
+        help="0=silent, 1=dot-mode, 2=run-trace 3=full-trace",
     )
     parser.add_argument(
         "--include_dirs",
@@ -455,10 +494,7 @@ def main():
         help="Run these colon-delimited groups. If not specified, only zests with no group will run",
     )
     parser.add_argument(
-        "--skip_groups",
-        type=str,
-        nargs="?",
-        help="Skip these colon-delimited groups.",
+        "--skip_groups", type=str, nargs="?", help="Skip these colon-delimited groups.",
     )
     parser.add_argument(
         "--disable_shuffle",
@@ -472,7 +508,9 @@ def main():
         "--version", action="store_true", help="Show version and exit",
     )
     parser.add_argument(
-        "--bypass_skip", nargs="?", help="Run test even if it was skipped given this skip tag",
+        "--bypass_skip",
+        nargs="?",
+        help="Run test even if it was skipped given this skip tag",
     )
     parser.add_argument(
         "match_string", type=str, nargs="?", help="Optional substring to match"
